summaryrefslogtreecommitdiff
path: root/svx/inc/svx/svdglev.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'svx/inc/svx/svdglev.hxx')
-rw-r--r--svx/inc/svx/svdglev.hxx34
1 files changed, 17 insertions, 17 deletions
diff --git a/svx/inc/svx/svdglev.hxx b/svx/inc/svx/svdglev.hxx
index 88cd48974f9c..efded3a48182 100644
--- a/svx/inc/svx/svdglev.hxx
+++ b/svx/inc/svx/svdglev.hxx
@@ -61,7 +61,7 @@ class SVX_DLLPUBLIC SdrGlueEditView: public SdrPolyEditView
void ImpCopyMarkedGluePoints();
typedef void (*PGlueDoFunc)(SdrGluePoint&, const SdrObject* pObj, const void*, const void*, const void*, const void*, const void*);
typedef void (*PGlueTrFunc)(Point&, const void*, const void*, const void*, const void*, const void*);
- void ImpDoMarkedGluePoints(PGlueDoFunc pDoFunc, BOOL bConst, const void* p1=NULL, const void* p2=NULL, const void* p3=NULL, const void* p4=NULL, const void* p5=NULL);
+ void ImpDoMarkedGluePoints(PGlueDoFunc pDoFunc, sal_Bool bConst, const void* p1=NULL, const void* p2=NULL, const void* p3=NULL, const void* p4=NULL, const void* p5=NULL);
void ImpTransformMarkedGluePoints(PGlueTrFunc pTrFunc, const void* p1=NULL, const void* p2=NULL, const void* p3=NULL, const void* p4=NULL, const void* p5=NULL);
protected:
@@ -74,15 +74,15 @@ public:
// checken bzw. setzen/loeschen will.
// Moegliche Werte fuer nThisEsc sind z.Zt.
// SDRESC_LEFT, SDRESC_RIGHT, SDRESC_TOP und SDRESC_BOTTOM
- TRISTATE IsMarkedGluePointsEscDir(USHORT nThisEsc) const;
- void SetMarkedGluePointsEscDir(USHORT nThisEsc, BOOL bOn);
- BOOL IsSetMarkedGluePointsEscDirPossible() const { return !IsReadOnly() && HasMarkedGluePoints(); }
+ TRISTATE IsMarkedGluePointsEscDir(sal_uInt16 nThisEsc) const;
+ void SetMarkedGluePointsEscDir(sal_uInt16 nThisEsc, sal_Bool bOn);
+ sal_Bool IsSetMarkedGluePointsEscDirPossible() const { return !IsReadOnly() && HasMarkedGluePoints(); }
// Checken/setzen, ob die Klebepunktpositionen relativ zur
// Objektgroesse sind (Percent=TRUE) oder nicht (Percent=FALSE)
TRISTATE IsMarkedGluePointsPercent() const;
- void SetMarkedGluePointsPercent(BOOL bOn);
- BOOL IsSetMarkedGluePointsPercentPossible() const { return !IsReadOnly() && HasMarkedGluePoints(); }
+ void SetMarkedGluePointsPercent(sal_Bool bOn);
+ sal_Bool IsSetMarkedGluePointsPercentPossible() const { return !IsReadOnly() && HasMarkedGluePoints(); }
// bVert=FALSE: Horizontales Alignment checken/setzen
// SDRHORZALIGN_CENTER
@@ -94,23 +94,23 @@ public:
// SDRVERTALIGN_TOP
// SDRVERTALIGN_BOTTOM
// SDRVERTALIGN_DONTCARE (nur bei Get())
- USHORT GetMarkedGluePointsAlign(BOOL bVert) const;
- void SetMarkedGluePointsAlign(BOOL bVert, USHORT nAlign);
- BOOL IsSetMarkedGluePointsAlignPossible() const { return !IsReadOnly() && HasMarkedGluePoints(); }
+ sal_uInt16 GetMarkedGluePointsAlign(sal_Bool bVert) const;
+ void SetMarkedGluePointsAlign(sal_Bool bVert, sal_uInt16 nAlign);
+ sal_Bool IsSetMarkedGluePointsAlignPossible() const { return !IsReadOnly() && HasMarkedGluePoints(); }
// Alle merkierten Klebepunkte entfernen
void DeleteMarkedGluePoints();
- BOOL IsDeleteMarkedGluePointsPossible() const;
+ sal_Bool IsDeleteMarkedGluePointsPossible() const;
void MoveMarkedGluePoints (const Size& rSiz, bool bCopy=false);
void ResizeMarkedGluePoints(const Point& rRef, const Fraction& xFact, const Fraction& yFact, bool bCopy=false);
void RotateMarkedGluePoints(const Point& rRef, long nWink, bool bCopy=false);
- void MirrorMarkedGluePoints(const Point& rRef1, const Point& rRef2, BOOL bCopy=FALSE);
- void MirrorMarkedGluePointsHorizontal(BOOL bCopy=FALSE);
- void MirrorMarkedGluePointsVertical(BOOL bCopy=FALSE);
- void ShearMarkedGluePoints(const Point& rRef, long nWink, BOOL bVShear=FALSE, BOOL bCopy=FALSE);
- void CrookMarkedGluePoints(const Point& rRef, const Point& rRad, SdrCrookMode eMode, BOOL bVertical=FALSE, BOOL bNoContortion=FALSE, BOOL bCopy=FALSE);
- void DistortMarkedGluePoints(const Rectangle& rRef, const XPolygon& rDistortedRect, BOOL bNoContortion=FALSE, BOOL bCopy=FALSE);
+ void MirrorMarkedGluePoints(const Point& rRef1, const Point& rRef2, sal_Bool bCopy=sal_False);
+ void MirrorMarkedGluePointsHorizontal(sal_Bool bCopy=sal_False);
+ void MirrorMarkedGluePointsVertical(sal_Bool bCopy=sal_False);
+ void ShearMarkedGluePoints(const Point& rRef, long nWink, sal_Bool bVShear=sal_False, sal_Bool bCopy=sal_False);
+ void CrookMarkedGluePoints(const Point& rRef, const Point& rRad, SdrCrookMode eMode, sal_Bool bVertical=sal_False, sal_Bool bNoContortion=sal_False, sal_Bool bCopy=sal_False);
+ void DistortMarkedGluePoints(const Rectangle& rRef, const XPolygon& rDistortedRect, sal_Bool bNoContortion=sal_False, sal_Bool bCopy=sal_False);
void AlignMarkedGluePoints(SdrHorAlign eHor, SdrVertAlign eVert);
};
@@ -74,15 +74,15 @@ public:
// Checken/setzen, ob die Klebepunktpositionen relativ zur
- // Objektgroesse sind (Percent=TRUE) oder nicht (Percent=FALSE)
+ // Objektgroesse sind (Percent=sal_True) oder nicht (Percent=sal_False)
TRISTATE IsMarkedGluePointsPercent() const;